@@ -1,6 +1,6 @@
 -- 
 -- Created by SQL::Translator::Producer::MySQL
--- Created on Wed Oct  7 09:30:59 2009
+-- Created on Wed Jan 20 15:06:15 2010
 -- 
 SET foreign_key_checks=0;
 
@@ -40,6 +40,25 @@ CREATE TABLE `reportgrouptestrun` (
   PRIMARY KEY (`testrun_id`, `report_id`)
 ) ENGINE=InnoDB;
 
+DROP TABLE IF EXISTS `reportgrouptestrunstats`;
+
+--
+-- Table: `reportgrouptestrunstats`
+--
+CREATE TABLE `reportgrouptestrunstats` (
+  `testrun_id` integer(11) NOT NULL,
+  `total` integer(10),
+  `failed` integer(10),
+  `passed` integer(10),
+  `parse_errors` integer(10),
+  `skipped` integer(10),
+  `todo` integer(10),
+  `todo_passed` integer(10),
+  `wait` integer(10),
+  `success_ratio` VARCHAR(20),
+  PRIMARY KEY (`testrun_id`)
+);
+
 DROP TABLE IF EXISTS `reportsection`;
 
 --
@@ -57,6 +76,7 @@ CREATE TABLE `reportsection` (
   `description` VARCHAR(255),
   `language_description` text,
   `cpuinfo` text,
+  `bios` text,
   `ram` VARCHAR(50),
   `uptime` VARCHAR(50),
   `lspci` text,
@@ -91,6 +111,7 @@ CREATE TABLE `suite` (
   `name` VARCHAR(255) NOT NULL,
   `type` VARCHAR(50) NOT NULL,
   `description` text NOT NULL,
+  INDEX suite_idx_name (`name`),
   PRIMARY KEY (`id`)
 ) ENGINE=InnoDB;
 
@@ -143,9 +164,10 @@ CREATE TABLE `report` (
   `updated_at` datetime NOT NULL,
   INDEX report_idx_id (`id`),
   INDEX report_idx_suite_id (`suite_id`),
+  INDEX report_idx_machine_name (`machine_name`),
   PRIMARY KEY (`id`),
   CONSTRAINT `report_fk_id` FOREIGN KEY (`id`) REFERENCES `reportgrouparbitrary` (`report_id`) ON DELETE CASCADE ON UPDATE CASCADE,
-  CONSTRAINT `report_fk_id_1` FOREIGN KEY (`id`) REFERENCES `reportgrouptestrun` (`report_id`) ON DELETE CASCADE ON UPDATE CASCADE,
+  CONSTRAINT `report_fk_id_1` FOREIGN KEY (`id`) REFERENCES `reportgrouptestrun` (`report_id`),
   CONSTRAINT `report_fk_suite_id` FOREIGN KEY (`suite_id`) REFERENCES `suite` (`id`) ON DELETE CASCADE ON UPDATE CASCADE
 ) ENGINE=InnoDB;
 
@@ -191,6 +213,7 @@ CREATE TABLE `reportcomment` (
   `id` integer(11) NOT NULL auto_increment,
   `report_id` integer(11) NOT NULL,
   `user_id` integer(11),
+  `succession` integer(10),
   `comment` text NOT NULL DEFAULT '',
   `created_at` datetime NOT NULL,
   `updated_at` datetime NOT NULL,
@@ -203,3 +226,17 @@ CREATE TABLE `reportcomment` (
 
 SET foreign_key_checks=1;
 
+--
+-- View: view_testrun_overview_reports
+--
+DROP VIEW IF EXISTS view_testrun_overview_reports;
+CREATE VIEW view_testrun_overview_reports AS
+    select rgts.testrun_id    as rgt_testrun_id,        max(rgt.report_id) as primary_report_id,        rgts.success_ratio as rgts_success_ratio from reportgrouptestrun rgt, reportgrouptestrunstats rgts where rgt.testrun_id=rgts.testrun_id group by rgt.testrun_id;
+
+--
+-- View: view_testrun_overview
+--
+DROP VIEW IF EXISTS view_testrun_overview;
+CREATE VIEW view_testrun_overview AS
+    select vtor.*,        r.machine_name,        r.created_at,        r.suite_id,        s.name as suite_name from view_testrun_overview_reports vtor,      report r,      suite s where vtor.primary_report_id=r.id and       r.suite_id=s.id;
+
